You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@maven.apache.org by ol...@apache.org on 2011/11/08 22:50:47 UTC

svn commit: r1199474 - in /maven/shared/trunk/maven-script-interpreter/src/main/java/org/apache/maven/shared/scriptinterpreter: BuildErrorException.java RunErrorException.java ScriptRunner.java

Author: olamy
Date: Tue Nov  8 21:50:47 2011
New Revision: 1199474

URL: http://svn.apache.org/viewvc?rev=1199474&view=rev
Log:
rename BuildErrorException to RunErrorException as we are running a script here

Added:
    maven/shared/trunk/maven-script-interpreter/src/main/java/org/apache/maven/shared/scriptinterpreter/RunErrorException.java   (contents, props changed)
      - copied, changed from r1196162, maven/shared/trunk/maven-script-interpreter/src/main/java/org/apache/maven/shared/scriptinterpreter/BuildErrorException.java
Removed:
    maven/shared/trunk/maven-script-interpreter/src/main/java/org/apache/maven/shared/scriptinterpreter/BuildErrorException.java
Modified:
    maven/shared/trunk/maven-script-interpreter/src/main/java/org/apache/maven/shared/scriptinterpreter/ScriptRunner.java

Copied: maven/shared/trunk/maven-script-interpreter/src/main/java/org/apache/maven/shared/scriptinterpreter/RunErrorException.java (from r1196162, maven/shared/trunk/maven-script-interpreter/src/main/java/org/apache/maven/shared/scriptinterpreter/BuildErrorException.java)
URL: http://svn.apache.org/viewvc/maven/shared/trunk/maven-script-interpreter/src/main/java/org/apache/maven/shared/scriptinterpreter/RunErrorException.java?p2=maven/shared/trunk/maven-script-interpreter/src/main/java/org/apache/maven/shared/scriptinterpreter/RunErrorException.java&p1=maven/shared/trunk/maven-script-interpreter/src/main/java/org/apache/maven/shared/scriptinterpreter/BuildErrorException.java&r1=1196162&r2=1199474&rev=1199474&view=diff
==============================================================================
--- maven/shared/trunk/maven-script-interpreter/src/main/java/org/apache/maven/shared/scriptinterpreter/BuildErrorException.java (original)
+++ maven/shared/trunk/maven-script-interpreter/src/main/java/org/apache/maven/shared/scriptinterpreter/RunErrorException.java Tue Nov  8 21:50:47 2011
@@ -26,7 +26,7 @@ package org.apache.maven.shared.scriptin
  * @author Stephen Connolly
  * @version $Id$
  */
-public class BuildErrorException
+public class RunErrorException
     extends BuildFailureException
 {
 
@@ -42,7 +42,7 @@ public class BuildErrorException
      * @param type The type of build failure, may not be <code>null</code>.
      * @param cause The cause of the build error.
      */
-    public BuildErrorException( String message, String type, Throwable cause )
+    public RunErrorException( String message, String type, Throwable cause )
     {
         super( message, type );
         initCause( cause );

Propchange: maven/shared/trunk/maven-script-interpreter/src/main/java/org/apache/maven/shared/scriptinterpreter/RunErrorException.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: maven/shared/trunk/maven-script-interpreter/src/main/java/org/apache/maven/shared/scriptinterpreter/RunErrorException.java
------------------------------------------------------------------------------
    svn:keywords = Author Date Id Revision

Modified: maven/shared/trunk/maven-script-interpreter/src/main/java/org/apache/maven/shared/scriptinterpreter/ScriptRunner.java
URL: http://svn.apache.org/viewvc/maven/shared/trunk/maven-script-interpreter/src/main/java/org/apache/maven/shared/scriptinterpreter/ScriptRunner.java?rev=1199474&r1=1199473&r2=1199474&view=diff
==============================================================================
--- maven/shared/trunk/maven-script-interpreter/src/main/java/org/apache/maven/shared/scriptinterpreter/ScriptRunner.java (original)
+++ maven/shared/trunk/maven-script-interpreter/src/main/java/org/apache/maven/shared/scriptinterpreter/ScriptRunner.java Tue Nov  8 21:50:47 2011
@@ -149,7 +149,7 @@ public class ScriptRunner
      * @param logger             The logger to redirect the script output to, may be <code>null</code> to use stdout/stderr.
      * @param stage              The stage of the build job the script is invoked in, must not be <code>null</code>.
      * @param failOnException    If <code>true</code> and the script throws an exception, then a {@link BuildFailureException}
      *                           will be thrown, otherwise a {@link BuildErrorException} will be thrown on script exception.
      * @throws org.apache.maven.plugin.MojoExecutionException
      *                               If an I/O error occurred while reading the script file.
      * @throws BuildFailureException If the script did not return <code>true</code> of threw an exception.
@@ -232,7 +232,7 @@ public class ScriptRunner
             }
             else
             {
-                throw new BuildErrorException( "The " + scriptDescription + " did not succeed. " + msg, stage, t );
+                throw new RunErrorException( "The " + scriptDescription + " did not succeed. " + msg, stage, t );
             }
         }
@@ -149,7 +149,7 @@ public class ScriptRunner
      * @param stage              The stage of the build job the script is invoked in, must not be <code>null</code>.
      * @param failOnException    If <code>true</code> and the script throws an exception, then a {@link BuildFailureException}
-     *                           will be thrown, otherwise a {@link BuildErrorException} will be thrown on script exception.
+     *                           will be thrown, otherwise a {@link RunErrorException} will be thrown on script exception.
      * @throws org.apache.maven.plugin.MojoExecutionException
      *                               If an I/O error occurred while reading the script file.